Crate replicante_util_iron

Crate replicante_util_iron 

Structs

MetricsHandler
An Iron Handler that exposes prometheus metrics in text format.
MetricsMiddleware
An Iron middlewere to collect metrics about endpoints.
RequestLogger
Iron middleware to log processed requests.
RootedRouter
Specialised router to mount endpoints under a fixed root.
Router
A builder object for an iron-router Router.
SentryMiddleware
Iron middleware that sends non-success responses to sentry.

Traits

RootDescriptor
Interface for types that describe endpoint roots.

Functions

into_ironerror
Helper function to convert a Fail into an IronError.
otr_into_ironerror
Convert an OpenTracingRust error into an IronError.
request_span
Access the request’s tracing span.