Structs
- Metrics
Handler - An Iron Handler that exposes prometheus metrics in text format.
- Metrics
Middleware - An Iron middlewere to collect metrics about endpoints.
- Request
Logger - Iron middleware to log processed requests.
- Rooted
Router - Specialised router to mount endpoints under a fixed root.
- Router
- A builder object for an
iron-routerRouter. - Sentry
Middleware - Iron middleware that sends non-success responses to sentry.
Traits
- Root
Descriptor - Interface for types that describe endpoint roots.
Functions
- into_
ironerror - Helper function to convert a
Failinto anIronError. - otr_
into_ ironerror - Convert an OpenTracingRust error into an IronError.
- request_
span - Access the request’s tracing span.